document.addEventListener('DOMContentLoaded', function() {
    let currentLanguage = 'fr';
    const languageSelect = document.getElementById('languageSelect');
    const title = document.getElementById('title');
    const generateBtn = document.getElementById('generateBtn');
    const passwordDisplay = document.getElementById('passwordDisplay');
    const copyMessage = document.getElementById('copyMessage');
    const settingsBtn = document.getElementById('settingsBtn');
    const settingsPopup = document.getElementById('settingsPopup');
    const closePopup = document.getElementById('closePopup');
    const settingsForm = document.getElementById('settingsForm');
    const accountTypesContainer = document.getElementById('accountTypesContainer');
    const addAccountTypeBtn = document.getElementById('addAccountTypeBtn');
    const saveBtn = document.getElementById('saveBtn');
    const accountType = document.getElementById('accountType');
    const specialCharsPopup = document.getElementById('specialCharsPopup');
    const closeSpecialCharsPopup = document.getElementById('closeSpecialCharsPopup');
    const saveSpecialCharsBtn = document.getElementById('saveSpecialCharsBtn');
    const specialCharsText = document.getElementById('specialCharsText');

    let passwordSettings = {};
    let currentType = null;

    function updateLanguage() {
        const t = translations[currentLanguage];
        title.textContent = t.title;
        generateBtn.textContent = t.generate;
        passwordDisplay.textContent = t.passwordPlaceholder;
        copyMessage.textContent = t.copyMessage;
        settingsBtn.textContent = t.settings;
        addAccountTypeBtn.textContent = t.addAccountType;
        saveBtn.textContent = t.save;
        
        updateAccountTypeSelector();

        document.querySelectorAll('.account-type-field').forEach(field => {
            updateAccountTypeField(field);
        });
    }

    function updateAccountTypeSelector() {
        const t = translations[currentLanguage];
        accountType.innerHTML = '';
        for (const type in passwordSettings) {
            const option = document.createElement('option');
            option.value = type;
            option.textContent = t[type] || type;
            accountType.appendChild(option);
        }
    }

    languageSelect.addEventListener('change', (event) => {
        currentLanguage = event.target.value;
        updateLanguage();
    });

    function populateAccountTypes() {
        accountTypesContainer.innerHTML = '';
        for (const [type, settings] of Object.entries(passwordSettings)) {
            addAccountTypeField(type, settings);
        }
    }

    function addAccountTypeField(type, settings) {
        const t = translations[currentLanguage];
        const div = document.createElement('div');
        div.classList.add('account-type-field');
        div.innerHTML = `
            <div class="account-type-header">
                <input type="text" class="account-type-name" value="${type}" readonly>
                <span class="removeAccountType">${t.remove}</span>
            </div>
            <div class="slider-container">
                <label for="${type}Length">${t.length}:</label>
                <input type="range" id="${type}Length" name="${type}Length" min="6" max="32" value="${settings.length}">
                <span class="slider-value">${settings.length}</span>
            </div>
            <div class="checkbox-container">
                <label><input type="checkbox" id="${type}Lowercase" name="${type}Lowercase" ${settings.lowercase ? 'checked' : ''}> ${t.lowercase}</label>
                <label><input type="checkbox" id="${type}Uppercase" name="${type}Uppercase" ${settings.uppercase ? 'checked' : ''}> ${t.uppercase}</label>
                <label><input type="checkbox" id="${type}Numbers" name="${type}Numbers" ${settings.numbers ? 'checked' : ''}> ${t.numbers}</label>
                <label>
                    <input type="checkbox" id="${type}Symbols" name="${type}Symbols" ${settings.symbols ? 'checked' : ''}> ${t.symbols}
                    <span class="open-special-chars-popup" data-type="${type}" style="cursor: pointer; text-decoration: underline;">&#x1F50D;</span>
                </label>
            </div>
        `;
        accountTypesContainer.appendChild(div);

        const slider = div.querySelector('input[type="range"]');
        const sliderValue = div.querySelector('.slider-value');
        
        slider.addEventListener('input', (event) => {
            sliderValue.textContent = event.target.value;
        });

        div.querySelector('.removeAccountType').addEventListener('click', () => {
            div.remove();
            delete passwordSettings[type];
            updateAccountTypeSelector();
            saveSettings();
        });

        const specialCharsBtn = div.querySelector('.open-special-chars-popup');
        specialCharsBtn.addEventListener('click', (event) => {
            currentType = event.target.dataset.type;
            specialCharsText.value = settings.specialChars || '!@#$%^&*()_+[]{}|;:,.<>?';
            specialCharsPopup.style.display = 'block';
        });
    }

    function updateAccountTypeField(field) {
        const t = translations[currentLanguage];
        field.querySelector('label[for$="Length"]').textContent = t.length + ':';
        field.querySelectorAll('.checkbox-container label').forEach((label, index) => {
            const checkboxLabels = [t.lowercase, t.uppercase, t.numbers, t.symbols];
            label.childNodes[1].textContent = ' ' + checkboxLabels[index];
        });
        field.querySelector('.removeAccountType').textContent = t.remove;
    }

    function generatePassword(settings) {
        const lowercase = 'abcdefghijkmnopqrstuvwxyz';
        const uppercase = 'ABCDEFGHJKLMNPQRSTUVWXYZ';
        const numbers = '23456789';
        const symbols = settings.specialChars || '!@#$%^&*()_+[]{}|;:,.<>?';
        
        let allChars = '';
        if (settings.lowercase) allChars += lowercase;
        if (settings.uppercase) allChars += uppercase;
        if (settings.numbers) allChars += numbers;
        if (settings.symbols) allChars += symbols;
        
        let password = '';
        for (let i = 0; i < settings.length; i++) {
            password += allChars[Math.floor(Math.random() * allChars.length)];
        }
        return password;
    }

    generateBtn.addEventListener('click', () => {
        const selectedType = accountType.value;
        const settings = passwordSettings[selectedType];
        const generatedPassword = generatePassword(settings);
        passwordDisplay.textContent = generatedPassword;
        copyMessage.style.display = 'block';
    });

    passwordDisplay.addEventListener('click', () => {
        const t = translations[currentLanguage];
        if (passwordDisplay.textContent !== t.passwordPlaceholder) {
            navigator.clipboard.writeText(passwordDisplay.textContent).then(() => {
                copyMessage.textContent = 'Password copied!';
                setTimeout(() => {
                    copyMessage.textContent = t.copyMessage;
                }, 2000);
            });
        }
    });

    settingsBtn.addEventListener('click', () => {
        settingsPopup.style.display = 'block';
    });

    closePopup.addEventListener('click', () => {
        settingsPopup.style.display = 'none';
    });

    closeSpecialCharsPopup.addEventListener('click', () => {
        specialCharsPopup.style.display = 'none';
    });

    window.addEventListener('click', (event) => {
        if (event.target === settingsPopup) {
            settingsPopup.style.display = 'none';
        }
        if (event.target === specialCharsPopup) {
            specialCharsPopup.style.display = 'none';
        }
    });

    saveSpecialCharsBtn.addEventListener('click', () => {
        if (currentType) {
            passwordSettings[currentType].specialChars = specialCharsText.value;
            specialCharsPopup.style.display = 'none';
            saveSettings();
        }
    });

    addAccountTypeBtn.addEventListener('click', () => {
        const t = translations[currentLanguage];
        const newType = prompt(t.accountTypePrompt);
        if (newType && !passwordSettings[newType]) {
            passwordSettings[newType] = {
                length: 12,
                lowercase: true,
                uppercase: true,
                numbers: true,
                symbols: true,
                specialChars: '!@#$%^&*()_+[]{}|;:,.<>?'
            };
            addAccountTypeField(newType, passwordSettings[newType]);
            updateAccountTypeSelector();
            saveSettings();
        } else if (passwordSettings[newType]) {
            alert(t.accountTypeExists || 'This account type already exists.');
        }
    });

    function saveSettings() {
        localStorage.setItem('passwordSettings', JSON.stringify(passwordSettings));
        fetch('save_settings.php', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({ passwordSettings })
        })
        .then(response => response.text())
        .then(data => {
            const t = translations[currentLanguage];
            console.log(t.saveSuccess);
        })
        .catch(error => console.error('Error saving settings:', error));
    }

    settingsForm.addEventListener('submit', (event) => {
        event.preventDefault();
        document.querySelectorAll('.account-type-field').forEach(field => {
            const type = field.querySelector('.account-type-name').value;
            const length = parseInt(field.querySelector(`input[name="${type}Length"]`).value);
            const lowercase = field.querySelector(`input[name="${type}Lowercase"]`).checked;
            const uppercase = field.querySelector(`input[name="${type}Uppercase"]`).checked;
            const numbers = field.querySelector(`input[name="${type}Numbers"]`).checked;
            const symbols = field.querySelector(`input[name="${type}Symbols"]`).checked;
            const specialChars = passwordSettings[type]?.specialChars || '!@#$%^&*()_+[]{}|;:,.<>?';
            passwordSettings[type] = { length, lowercase, uppercase, numbers, symbols, specialChars };
        });

        saveSettings();
        updateAccountTypeSelector();
        const t = translations[currentLanguage];
        alert(t.saveSuccess);
        populateAccountTypes();
        settingsPopup.style.display = 'none';
    });

    // Charger les paramètres depuis le localStorage ou le fichier JSON
    const savedSettings = localStorage.getItem('passwordSettings');
    if (savedSettings) {
        passwordSettings = JSON.parse(savedSettings);
        populateAccountTypes();
        updateAccountTypeSelector();
    } else {
        fetch('settings.json')
            .then(response => response.json())
            .then(data => {
                passwordSettings = data.passwordSettings;
                populateAccountTypes();
                updateAccountTypeSelector();
            })
            .catch(error => console.error('Erreur lors du chargement des paramètres:', error));
    }

    updateLanguage();
});